@@ -1,7 +1,7 @@
 
 ;;;### (autoloads nil "_pkg" "auctex/_pkg.el")
 
-(package-provide 'auctex :version 2014.1029 :author-version "11.88" :type 'regular)
+(package-provide 'auctex :version 2015.1113 :author-version "11.89" :type 'regular)
 
 ;;;***
 
@@ -77,6 +77,8 @@ It will setup BibTeX to store keys in an auto file." nil nil)
 
 (add-to-list 'auto-mode-alist '("\\.drv\\'" . latex-mode))
 
+(add-to-list 'auto-mode-alist '("\\.hva\\'" . latex-mode))
+
 (autoload 'TeX-latex-mode "latex" "\
 Major mode in AUCTeX for editing LaTeX files.
 See info under AUCTeX for full documentation.
@@ -163,7 +165,6 @@ files are no longer needed in the search path." t nil)
 Hook function for embedding the preview package into AUCTeX.
 This is called by `LaTeX-mode-hook' and changes AUCTeX variables
 to add the preview functionality." nil nil)
-(add-hook 'LaTeX-mode-hook #'LaTeX-preview-setup)
 
 (autoload 'preview-report-bug "preview" "\
 Report a bug in the preview-latex package." t nil)
@@ -424,19 +425,14 @@ set it with `TeX-modes-set'."
 		       `(TeX-modes-set ',var ,var t))
 		     (setq list (cdr list)))))) )
 
-(defconst AUCTeX-version "11.88"
+(defconst AUCTeX-version "11.89"
     "AUCTeX version.
 If not a regular release, the date of the last change.")
 
-(defconst AUCTeX-date "2014-10-29"
+(defconst AUCTeX-date "2015-11-13"
   "AUCTeX release date using the ISO 8601 format, yyyy-mm-dd.")
 
 ;; Store bibitems when saving a BibTeX buffer
 (add-hook 'bibtex-mode-hook 'BibTeX-auto-store)
 
 (provide 'tex-site)
-
-(defvar preview-lispdir (directory-file-name (file-name-directory load-file-name)))
-(add-to-list 'load-path preview-lispdir)
-(defvar preview-datadir (expand-file-name "../../etc/auctex" (file-name-directory load-file-name)))
-(defvar preview-TeX-style-dir (expand-file-name "../../etc/auctex/latex" (file-name-directory load-file-name)))
